import 'dart:ui';

import 'package:scanbot_sdk/json/common_data.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'check_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class CheckRecognizerJsonConfiguration {
  ///A version of the configuration object
  String? version;

  ///The configuration object should be applied for this screen
  String? screen;

  ///Accepted check standards. Optional, by default - all checks are accepted. With an empty list no filter is applied and all checks are accepted.
  List<CheckStandard>? acceptedCheckStandards;

  ///The preferred camera module (default - BACK)
  CameraModule? cameraModule;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color outside of the finder window.
  Color? cameraOverlayColor;

  ///Title of the cancel button.
  String? cancelButtonTitle;

  ///Set high-resolution Check image capturing. If set to TRUE a high-resolution photo of the check is captured to run the recognition on. Upon successful recognition the recognition result also contains a high-resolution image of the check. If set to FALSE, the video frames will be used for recognition and result image delivery. The default value is TRUE.
  bool? captureHighResolutionImage;

  ///Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  ///Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  ///Aspect ratio of finder frame (width \ height), which is used to build actual finder frame. Default is 1 - it is a square frame, which is good for QR capturing.
  FinderAspectRatio? finderAspectRatio;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the detection overlay.
  Color? finderLineColor;

  ///Width of finder frame border. Default is 2.
  double? finderLineWidth;

  ///Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  ///Title of the flash toggle button.
  String? flashButtonTitle;

  ///Controls whether the flash should be initially enabled. The default value is FALSE.
  bool? flashEnabled;

  ///UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The background color of the top toolbar.
  Color? topBarBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all active toggle buttons in the toolbar.
  Color? topBarButtonsActiveColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all inactive toggle buttons in the toolbar.
  Color? topBarButtonsInactiveColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The background color of the user guidance hints.
  Color? userGuidanceBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The text color of the user guidance hints.
  Color? userGuidanceTextColor;

  ///Configuration that helps to override default hint values.
  CheckUserGuidanceStrings? userGuidanceStringValues;

  ///Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  ///Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  CheckRecognizerJsonConfiguration({
    this.version,
    this.screen,
    this.acceptedCheckStandards,
    this.cameraModule,
    this.cameraOverlayColor,
    this.cancelButtonTitle,
    this.captureHighResolutionImage,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderAspectRatio,
    this.finderLineColor,
    this.finderLineWidth,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashEnabled,
    this.orientationLockMode,
    this.topBarBackgroundColor,
    this.topBarButtonsActiveColor,
    this.topBarButtonsInactiveColor,
    this.userGuidanceBackgroundColor,
    this.userGuidanceTextColor,
    this.userGuidanceStringValues,
    this.useButtonsAllCaps,
    this.cameraPreviewMode,
  });

  Map<String, dynamic> toJson() =>
      _$CheckRecognizerJsonConfigurationToJson(this);
}

/// Configuration that helps to override default hint values.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class CheckUserGuidanceStrings {
  /// Text that is shown on camera open.
  String startScanning;

  /// Text text that is shown when the camera is seeking for the document on the visible area, shown after the first result from the detector.
  String scanning;

  /// Text text that is shown when energy saving is active.
  String energySaving;

  /// Text that is shown when the camera snaps the image.
  String capturing;

  /// Text that is shown when the detector tries to detect the document from the snapped image.
  String processing;
  CheckUserGuidanceStrings(
    this.startScanning,
    this.scanning,
    this.energySaving,
    this.capturing,
    this.processing,
  );

  Map<String, dynamic> toJson() => _$CheckUserGuidanceStringsToJson(this);
}

/// Supported check standards.
enum CheckStandard {
  /// A check compatible with the ASC X9 standard used in the USA */
  USA,

  /// A check format commonly used in France */
  FRA,

  /// A check format commonly used in Kuwait */
  KWT,

  /// A check compatible with the Australian Paper Clearing System cheque standard */
  AUS,

  /// A check compatible with the CTS-2010 standard issued by the Reserve Bank of India in 2012 */
  IND,
}
