import 'dart:ui';

import 'package:scanbot_sdk/json/common_data.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'ehic_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class HealthInsuranceCardScannerJsonConfiguration {
  ///A version of the configuration object
  String? version;

  ///The configuration object should be applied for this screen
  String? screen;

  ///The preferred camera module (default - BACK)
  CameraModule? cameraModule;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color outside of the finder window.
  Color? cameraOverlayColor;

  ///Title of the cancel button.
  String? cancelButtonTitle;

  ///String being displayed when health insurance card was not found.
  String? detectionStatusFailedDetectionText;

  ///String being displayed when health insurance card was found but not recognized.
  String? detectionStatusFailedValidationText;

  ///String being displayed when health insurance card was found and recognized.
  String? detectionStatusSuccessText;

  ///Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  ///Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the detection overlay.
  Color? finderLineColor;

  ///Width of finder frame border. Default is 2.
  double? finderLineWidth;

  ///String being displayed as description.
  String? finderTextHint;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the description label.
  Color? finderTextHintColor;

  ///Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  ///Title of the flash toggle button.
  String? flashButtonTitle;

  ///Controls whether the flash should be initially enabled. The default value is FALSE.
  bool? flashEnabled;

  ///UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The background color of the top toolbar.
  Color? topBarBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all active toggle buttons in the toolbar.
  Color? topBarButtonsActiveColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all inactive toggle buttons in the toolbar.
  Color? topBarButtonsInactiveColor;

  ///Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  ///If `true`, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
  bool? replaceCancelButtonWithIcon;

  ///Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  HealthInsuranceCardScannerJsonConfiguration({
    this.version,
    this.screen,
    this.cameraModule,
    this.cameraOverlayColor,
    this.cancelButtonTitle,
    this.detectionStatusFailedDetectionText,
    this.detectionStatusFailedValidationText,
    this.detectionStatusSuccessText,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderLineColor,
    this.finderLineWidth,
    this.finderTextHint,
    this.finderTextHintColor,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashEnabled,
    this.orientationLockMode,
    this.topBarBackgroundColor,
    this.topBarButtonsActiveColor,
    this.topBarButtonsInactiveColor,
    this.useButtonsAllCaps,
    this.replaceCancelButtonWithIcon,
    this.cameraPreviewMode,
  });

  Map<String, dynamic> toJson() =>
      _$HealthInsuranceCardScannerJsonConfigurationToJson(this);
}
