import 'dart:ui';

import 'package:scanbot_sdk/json/common_data.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'mc_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class MedicalCertificateRecognizerJsonConfiguration {
  ///A version of the configuration object
  String? version;

  ///The configuration object should be applied for this screen
  String? screen;

  ///The preferred camera module (default - BACK)
  CameraModule? cameraModule;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color outside of the finder window.
  Color? cameraOverlayColor;

  ///Title of the cancel button.
  String? cancelButtonTitle;

  ///Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  ///Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the detection overlay.
  Color? finderLineColor;

  ///Width of finder frame border. Default is 2.
  double? finderLineWidth;

  ///Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  ///Title of the flash toggle button.
  String? flashButtonTitle;

  ///Controls whether the flash should be initially enabled. The default value is FALSE.
  bool? flashEnabled;

  ///UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The background color of the top toolbar.
  Color? topBarBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all active toggle buttons in the toolbar.
  Color? topBarButtonsActiveColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all inactive toggle buttons in the toolbar.
  Color? topBarButtonsInactiveColor;

  ///Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The background color of the user guidance hints.
  Color? userGuidanceBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The text color of the user guidance hints.
  Color? userGuidanceTextColor;

  ///Whether sdk should run recognition of Patient Information block.
  bool? recognizePatientInfo;

  ///Whether sdk should return cropped document image or not
  bool? returnCroppedDocumentImage;

  ///Error dialog title
  String? errorDialogTitle;

  ///Error dialog message
  String? errorDialogMessage;

  ///Error dialog ok button text
  String? errorDialogOkButton;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The accent color of buttons on a error dialog
  Color? errorDialogAccentColor;

  ///Allows to set if the confirm button should be filled
  bool? errorDialogOkButtonFilled;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Allows to set a text color of the filled button
  Color? errorDialogOkButtonFilledTextColor;

  ///Option to show or hide finder overlay
  bool? showFinderOverlay;

  ///Configuration that helps to override default hint values
  MedicalCertificateUserGuidanceStrings? userGuidanceStrings;

  ///Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  MedicalCertificateRecognizerJsonConfiguration({
    this.version,
    this.screen,
    this.cameraModule,
    this.cameraOverlayColor,
    this.cancelButtonTitle,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderLineColor,
    this.finderLineWidth,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashEnabled,
    this.orientationLockMode,
    this.topBarBackgroundColor,
    this.topBarButtonsActiveColor,
    this.topBarButtonsInactiveColor,
    this.useButtonsAllCaps,
    this.userGuidanceBackgroundColor,
    this.userGuidanceTextColor,
    this.recognizePatientInfo,
    this.returnCroppedDocumentImage,
    this.errorDialogTitle,
    this.errorDialogMessage,
    this.errorDialogOkButton,
    this.errorDialogAccentColor,
    this.errorDialogOkButtonFilled,
    this.errorDialogOkButtonFilledTextColor,
    this.showFinderOverlay,
    this.userGuidanceStrings,
    this.cameraPreviewMode,
  });

  Map<String, dynamic> toJson() =>
      _$MedicalCertificateRecognizerJsonConfigurationToJson(this);
}

/// Configuration for the hint values
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class MedicalCertificateUserGuidanceStrings {
  /// Text that is shown on camera open.
  String startScanning;

  /// Text text that is shown when the camera is seeking for the document on the visible area, shown after the first result from the detector.
  String scanning;

  /// Text text that is shown when energy saving is active.
  String energySaving;

  /// Text that is shown when the camera snaps the image.
  String capturing;

  /// Text that is shown when the detector tries to detect the document from the snapped image.
  String processing;
  MedicalCertificateUserGuidanceStrings(
    this.startScanning,
    this.scanning,
    this.energySaving,
    this.capturing,
    this.processing,
  );

  Map<String, dynamic> toJson() =>
      _$MedicalCertificateUserGuidanceStringsToJson(this);
}
