import 'dart:ui';

import 'package:scanbot_sdk/json/common_data.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'nfc_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class NfcScannerJsonConfiguration {
  ///A version of the configuration object
  String? version;

  ///The configuration object should be applied for this screen
  String? screen;

  ///The preferred camera module (default - BACK)
  CameraModule? cameraModule;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color outside of the finder window.
  Color? cameraOverlayColor;

  ///Title of the cancel button.
  String? cancelButtonTitle;

  ///Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  ///Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the detection overlay.
  Color? finderLineColor;

  ///Width of finder frame border. Default is 2.
  double? finderLineWidth;

  ///String being displayed as description.
  String? finderTextHint;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the description label.
  Color? finderTextHintColor;

  ///Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  ///Title of the flash toggle button.
  String? flashButtonTitle;

  ///Controls whether the flash should be initially enabled. The default value is FALSE.
  bool? flashEnabled;

  ///UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  ///Controls whether to play a beep sound after a successful detection. Default value is TRUE.
  bool? successBeepEnabled;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The background color of the top toolbar.
  Color? topBarBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all active toggle buttons in the toolbar.
  Color? topBarButtonsActiveColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of all inactive toggle buttons in the toolbar.
  Color? topBarButtonsInactiveColor;

  ///Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  ///A title for the screen of passport scanning.
  String? scanPassportTitle;

  ///A title for the state when the user should start scanning data from the NFC chip
  String? holdOverTheChipTitle;

  ///A title for the state when the data is loading from the NFC chip
  String? downloadingDataTitle;

  ///A title for the state when the error happened during the data loading from the NFC chip
  String? downloadErrorTitle;

  ///A title for the state when the error happened during the data loading from the NFC chip because of the wrong MRZ data, so the data cannot be processed
  String? authenticationErrorTitle;

  ///A title for the state when there is no hardware for NFC scanning installed on the device
  String? chipDisabledErrorTitle;

  ///A title for the state when the NFC chip is disabled on the device
  String? noChipErrorTitle;

  ///A title for the retry button
  String? retryButtonTitle;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///The color of progress bar during NFC scanning
  Color? progressBarColor;

  ///If `true`, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
  bool? replaceCancelButtonWithIcon;

  ///Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  NfcScannerJsonConfiguration({
    this.version,
    this.screen,
    this.cameraModule,
    this.cameraOverlayColor,
    this.cancelButtonTitle,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderLineColor,
    this.finderLineWidth,
    this.finderTextHint,
    this.finderTextHintColor,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashEnabled,
    this.orientationLockMode,
    this.successBeepEnabled,
    this.topBarBackgroundColor,
    this.topBarButtonsActiveColor,
    this.topBarButtonsInactiveColor,
    this.useButtonsAllCaps,
    this.scanPassportTitle,
    this.holdOverTheChipTitle,
    this.downloadingDataTitle,
    this.downloadErrorTitle,
    this.authenticationErrorTitle,
    this.chipDisabledErrorTitle,
    this.noChipErrorTitle,
    this.retryButtonTitle,
    this.progressBarColor,
    this.replaceCancelButtonWithIcon,
    this.cameraPreviewMode,
  });

  Map<String, dynamic> toJson() => _$NfcScannerJsonConfigurationToJson(this);
}
